@@ -1248,8 +1248,11 @@ class RedisRoot:
         return updated_data
 
     def _get_allowed_redis_model_params(self, params, redis_model):
-        redis_model_fields_names = redis_model.__model_data__.keys()
-        result_params = list(filter(lambda param_name: param_name in redis_model_fields_names, params.keys()))
+        redis_model_fields_names = redis_model.__dict__.keys()
+        result_params = list(filter(
+            lambda param_name: param_name in redis_model_fields_names and not param_name.startswith('__'),
+            params.keys()
+        ))
         return result_params
 
     def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None,
